@@ -15,6 +15,6 @@ exportEvents.redcapApiConnection <- function(rcon, arms, ...){
   #*** For classic projects, we want to avoid throwing a disruptive error. Instead, we 
   #*** return the message that indicates this is a classic project.
   else if (x$status_code == "400" & as.character(x) == "You cannot export events for classic projects") 
-    paste(x$status_code, ": ", as.character(x), sep="")
+    paste0(x$status_code, ": ", as.character(x))
   else stop(paste(x$status_code, ": ", as.character(x), sep=""))
 }
