@@ -12,6 +12,6 @@ exportInstruments.redcapApiConnection <- function(rcon, ...){
   if (x$status_code == "200")
     read.csv(textConnection(as.character(x)), stringsAsFactors=FALSE) 
   else if (x$status_code == "400" & as.character(x) == "The value of the parameter \"content\" is not valid") 
-    paste(x$status_code, ": ", as.character(x), sep="")
-  else stop(paste(x$status_code, ": ", as.character(x), sep=""))
+    paste0(x$status_code, ": ", as.character(x))
+  else stop(paste0(x$status_code, ": ", as.character(x)))
 }
