@@ -18,12 +18,12 @@ fieldToVar <-
     
     #* Time (MM:SS)
     else if (grepl("time_mm_ss", m$text_validation_type_or_show_slider_number) && dates){
-      d <- chron::times(ifelse(!is.na(d), paste("00:", d, sep=""), d), format=c(times="h:m:s"))
+      d <- chron::times(ifelse(!is.na(d), paste0("00:", d), d), format=c(times="h:m:s"))
     }
     
     #* Time (HH:MM)
     else if ("time" %in% m$text_validation_type_or_show_slider_number && dates){
-      d <- chron::times(ifelse(!is.na(d), paste(d, ":00", sep=""), d), format=c(times="h:m:s"))
+      d <- chron::times(ifelse(!is.na(d), paste0(d, ":00"), d), format=c(times="h:m:s"))
     }
     
     # Continuous variables
